Timeout class

Inheritance

Constructors

Timeout(Duration duration)
const

Properties

duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
isCanceled bool
no setterinherited
isFailure bool
no setterinherited
isIdle bool
no setterinherited
isLoading bool
no setterinherited
isSuccess bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited